using UnityEngine;
using UnityEngine.Events;

namespace WWII
{
  public class AmmoBehaviour : MonoBehaviour
  {
      public bool Auto;
      public float FireRate;
      public int MaxAmmo = 999999;
      public int TrueMaxAmmo;
      public int CurrentAmmo;
      public int ViewID = 0;
      public FirearmBehaviour Fire;
      public AudioSource ReloadSound;
      public AudioSource NOSound;
      float Counter = 0f;

      void Awake()                                                                                               //<-- Audio
      {
        ReloadSound = gameObject.AddComponent<AudioSource>();
        NOSound = gameObject.AddComponent<AudioSource>();

        ReloadSound.volume = 4f;
        ReloadSound.minDistance = 15f;
        ReloadSound.spatialBlend = 1f;
        ReloadSound.dopplerLevel = 0.0f;

        NOSound.volume = 2.5f;
        NOSound.minDistance = 15f;
        NOSound.spatialBlend = 1f;
        NOSound.dopplerLevel = 0.0f;
        NOSound.clip = ModAPI.LoadSound("Sounds/Featured/no sound.mp3");
      }

      private void Start()
      {
              Auto = gameObject.GetComponent<FirearmBehaviour>().Automatic;
              FireRate = gameObject.GetComponent<FirearmBehaviour>().AutomaticFireInterval;
              gameObject.GetComponent<FirearmBehaviour>().IgnoreUse = true;

              if (TrueMaxAmmo <= 0)
              {
                  TrueMaxAmmo = 30;
              }
              if (FireRate <= 0)
              {
                  FireRate = 0.1f;
              }
              CurrentAmmo = MaxAmmo;
              Counter = FireRate;
              ViewID = 0;
              Buttons();
      }

      void Buttons()                                                                                            //<-- Menu Buttons
      {
        this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("limited ammo", "<color=red>Limited Ammo", "<color=red>Makes them limited.", () =>
          {
              if (CurrentAmmo > TrueMaxAmmo)
              {
              CurrentAmmo = TrueMaxAmmo;
              }
              if (CurrentAmmo <= TrueMaxAmmo)
              {
              CurrentAmmo = CurrentAmmo;
              }
              ModAPI.Notify("Infinity Ammo <color=red> OFF");
              ViewID = 1;
          }));
          this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("limited ammo hidden", "<color=red>Limited Ammo <color=#3C8FD8>HIDE", "<color=#3C8FD8>The same limited amount of ammo only without pop-up messages. Useful if you are shooting a video or film.", () =>
            {
                if (CurrentAmmo > TrueMaxAmmo)
                {
                CurrentAmmo = TrueMaxAmmo;
                }
                if (CurrentAmmo <= TrueMaxAmmo)
                {
                CurrentAmmo = CurrentAmmo;
                }
                ModAPI.Notify("Infinity Ammo <color=red> OFF");
                ViewID = 0;
            }));
          this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("ammo int", "<color=green>Show Ammo", "<color=green>Shows your current ammo.", () =>
            {
                if (CurrentAmmo < TrueMaxAmmo)
                {
                ModAPI.Notify("<color=yellow>Ammo: </color><color=red>" + CurrentAmmo + "<color=yellow>/</color><color=green>" + TrueMaxAmmo);
                }
                if (CurrentAmmo >= TrueMaxAmmo)
                {
                  ModAPI.Notify("<color=yellow>Ammo: </color><color=green>" + TrueMaxAmmo + "<color=yellow>/</color>" + TrueMaxAmmo);
                }
            }));
        this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("ammo reload", "<color=yellow>Reload Ammo", "<color=yellow>Reload if no ammo.", () =>
          {
              if (CurrentAmmo <= TrueMaxAmmo)
              {
              CurrentAmmo = TrueMaxAmmo;
              }
              if (CurrentAmmo > TrueMaxAmmo)
              {
              CurrentAmmo = MaxAmmo;
              }
              ModAPI.Notify("<color=yellow>Reloaded");

              ReloadSound.Play();
          }));
        this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("infinity ammo", "<color=#30FFF8>Infinity Ammo", "<color=#30FFF8>Makes them infinity.", () =>
          {
              CurrentAmmo = MaxAmmo;
              ModAPI.Notify("Infinity Ammo<color=green> ON");
          }));
      }

      void Update()
      {
        if (CurrentAmmo < 1)
        {
            CurrentAmmo = 0;
        }

        Counter += Time.deltaTime;
      }


      void Use()
      {
          if (Counter > FireRate)
          {
              FireGun();
          }
          if (CurrentAmmo == 0)
          {
             if (ViewID == 1)
             {
             ModAPI.Notify("<color=red>NO Ammo");                                                              //<-- Ammo Screen (No Ammo)#1
             }
             NOSound.Play();
          }
      }


      void UseContinuous()
      {
          if (Auto == true)
          {
              if (Counter > FireRate)
              {
                  FireGun();
              }
          }
          if (CurrentAmmo == 0)
          {
             if (ViewID == 1)
             {
             ModAPI.Notify("<color=red>NO Ammo");                                                              //<-- Ammo Screen (No Ammo)#2
             }
             NOSound.Play();
          }
      }

      void FireGun()
      {
          FirearmBehaviour Fire = this.gameObject.GetComponent<FirearmBehaviour>();

          if (CurrentAmmo > 0 && Counter > FireRate)
          {
              Counter = 0f;
              CurrentAmmo -= 1;
              Fire.Shoot();
              Counter = 0f;

              if (CurrentAmmo < TrueMaxAmmo && CurrentAmmo > 0 && Counter == 0f && ViewID == 1)                //<-- Ammo Screen
              {
                ModAPI.Notify("<color=yellow>Ammo: </color><color=red>" + CurrentAmmo + "<color=yellow>/</color><color=green>" + TrueMaxAmmo);
              }
          }
      }
   }
}
